==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ts/GraphicsViewPreferences_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Rulers and Scrollbars</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Władcy i przewijania</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show rulers</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Pokaż linijki</translatorcomment>
        <translation type="unfinished">Pokaż linijki</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show scrollbars</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Pokaż paski przewijania</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Cursor</source>
        <translatorcomment>--google--
&amp;Podświetl obiekt pod kursorem myszy
Podświetl obiekt pod kursorem myszy
Nie istnieje plik &apos;%1&apos; z obrazkiem kursora dla skórki.</translatorcomment>
        <translation type="unfinished">Kursor</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show crosshairs</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Pokaż krzyżyk</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show large crosshairs</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Pokazuj duże krzyżyki
Pokazuj duże krzyżyki</translatorcomment>
        <translation type="unfinished">Pokazuj duże krzyżyki</translation>
    </message>
    <message>
        <source>Grid</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
&amp;Siatka
Siatka
Pozycjonowanie siatki</translatorcomment>
        <translation type="obsolete">Siatka</translation>
    </message>
    <message>
        <source>Automatically scale grid</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Automatyczne skalowanie siatki</translatorcomment>
        <translation type="obsolete">Automatyczne skalowanie siatki</translation>
    </message>
    <message>
        <source>Solid grid lines</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Ciągłe linie siatki</translatorcomment>
        <translation type="obsolete">Ciągłe linie siatki</translation>
    </message>
    <message>
        <source>Minimal grid spacing (px):</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Minimalny odstęp siatki (piksele):</translatorcomment>
        <translation type="obsolete">Minimalny odstęp siatki (piksele):</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Auto Zoom</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Autozoom
&amp;Autozoom</translatorcomment>
        <translation type="unfinished">Autozoom</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Margin (px):</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Marża (px):</translation>
    </message>
    <message>
        <location line="+57"/>
        <source>Color Adjustment</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Regulacja kolorów</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Prevent white on white / black on black display</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Zapobiec biały na biały / czarny na czarnym ekranie</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Color lightness threshold:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Próg lekkość Kolor:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Linetypes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Pattern scale for lineweight 0.00mm:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Automatically use screen based linetypes in model view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Auto switch linetypes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Performance</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Wydajność</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Number of preview entities:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Liczba obiektów w podglądzie:</translatorcomment>
        <translation type="unfinished">Liczba obiektów w podglądzie:</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Text height display threshold (px):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display arcs as lines below this angle (degrees):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text height display threshold:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wysokość progu Text display:</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Selection</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Kontynuuj działanie
&amp;Wskaźnik do zaznaczania</translatorcomment>
        <translation type="unfinished">Wybrane strony</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Persistent Selection</source>
        <translatorcomment>--google--
&amp;Stałe zaznaczenia
Stałe zaznaczenia</translatorcomment>
        <translation type="unfinished">Persistent Selection</translation>
    </message>
</context>
<context>
    <name>GraphicsViewPreferences</name>
    <message>
        <location filename="../GraphicsViewPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Graphics View</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Appearance</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
&amp;Wygląd
Wygląd</translatorcomment>
        <translation type="unfinished">Wygląd</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ts/GraphicsViewPreferences_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+51"/>
        <source>Rulers and Scrollbars</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Władcy i przewijania</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show rulers</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Pokaż linijki</translatorcomment>
        <translation type="unfinished">Pokaż linijki</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show scrollbars</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Pokaż paski przewijania</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Cursor</source>
        <translatorcomment>--google--
&amp;Podświetl obiekt pod kursorem myszy
Podświetl obiekt pod kursorem myszy
Nie istnieje plik &apos;%1&apos; z obrazkiem kursora dla skórki.</translatorcomment>
        <translation type="unfinished">Kursor</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show crosshairs</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Pokaż krzyżyk</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show large crosshairs</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Pokazuj duże krzyżyki
Pokazuj duże krzyżyki</translatorcomment>
        <translation type="unfinished">Pokazuj duże krzyżyki</translation>
    </message>
    <message>
        <source>Grid</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
&amp;Siatka
Siatka
Pozycjonowanie siatki</translatorcomment>
        <translation type="obsolete">Siatka</translation>
    </message>
    <message>
        <source>Automatically scale grid</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Automatyczne skalowanie siatki</translatorcomment>
        <translation type="obsolete">Automatyczne skalowanie siatki</translation>
    </message>
    <message>
        <source>Solid grid lines</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Ciągłe linie siatki</translatorcomment>
        <translation type="obsolete">Ciągłe linie siatki</translation>
    </message>
    <message>
        <source>Minimal grid spacing (px):</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Minimalny odstęp siatki (piksele):</translatorcomment>
        <translation type="obsolete">Minimalny odstęp siatki (piksele):</translation>
    </message>
    <message>
        <location line="-64"/>
        <source>Origin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show large origin axis</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+71"/>
        <source>Auto Zoom</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Autozoom
&amp;Autozoom</translatorcomment>
        <translation type="unfinished">Autozoom</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Margin (px):</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Marża (px):</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Auto zoom on load</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Color Adjustment</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Regulacja kolorów</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Prevent white on white / black on black display</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Zapobiec biały na biały / czarny na czarnym ekranie</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Color lightness threshold:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Próg lekkość Kolor:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Linetypes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Auto switch to screen based linetypes in model view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale linetype patterns by line weight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Pattern scale for lineweight 0.00mm:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Display and Performance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+146"/>
        <source>Display entities with more than N dashes as continuous:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Minimum angle step for rendering arcs (degrees):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+144"/>
        <source>Use full resolution for Retina display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Anti-aliasing on by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Maximum number of reference points displayed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-76"/>
        <source>Timeout for hatch rendering:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-342"/>
        <source>Automatically use screen based linetypes in model view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Performance</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wydajność</translation>
    </message>
    <message>
        <location line="+78"/>
        <source>Number of preview entities:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Liczba obiektów w podglądzie:</translatorcomment>
        <translation type="unfinished">Liczba obiektów w podglądzie:</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Text height display threshold (px):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display arcs as lines below this angle (degrees):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text height display threshold:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wysokość progu Text display:</translation>
    </message>
    <message>
        <location line="+331"/>
        <source>Selection</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Kontynuuj działanie
&amp;Wskaźnik do zaznaczania</translatorcomment>
        <translation type="unfinished">Wybrane strony</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Persistent Selection</source>
        <translatorcomment>--google--
&amp;Stałe zaznaczenia
Stałe zaznaczenia</translatorcomment>
        <translation type="unfinished">Persistent Selection</translation>
    </message>
</context>
<context>
    <name>GraphicsViewPreferences</name>
    <message>
        <location filename="../GraphicsViewPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Graphics View</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Appearance</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
&amp;Wygląd
Wygląd</translatorcomment>
        <translation type="unfinished">Wygląd</translation>
    </message>
</context>
</TS>
